@@ -40,7 +40,7 @@ class Pou():
              f"{fg(self.terminal.TEXT_COLOR)}Exit"]
         )
 
-        if user_input == f"{fg(self.terminal.TEXT_COLOR)}Start": self.chatgpt()
+        if user_input == f"{fg(self.terminal.TEXT_COLOR)}Back to Terminal": self.chatgpt()
         if user_input == f"{fg(self.terminal.TEXT_COLOR)}Configure user credentials": self.configure_user_cred()
         if user_input == f"{fg(self.terminal.TEXT_COLOR)}Settings": self.settings()
         if user_input == f"{fg(self.terminal.TEXT_COLOR)}Exit": self.exit()
